@@ -541,7 +541,8 @@ class Bitpin:
 
         return self._process_response(f_name, response, f_args)
 
-    def create_order(self, market: int, order_type: str, side: str, amount: float, price: float = None) -> t.Dict:
+    def create_order(self, market: int, order_type: str, side: str, amount: float,
+                     price: float = None, order_id: str = None) -> t.Dict:
         """
         Create order.
 
@@ -560,6 +561,9 @@ class Bitpin:
         :param price: Price (optional)
         :type price: float
 
+        :param order_id: Order ID (optional)
+        :type order_id: str
+
         :return: Order
         :rtype: dict
         """
@@ -581,6 +585,9 @@ class Bitpin:
             'price_limit': price,
         }
 
+        if order_id:
+            json_data['order_id'] = order_id
+
         response = self._request(
             f_name,
             'POST',
@@ -681,3 +688,25 @@ class Bitpin:
         )
 
         return self._process_response(f_name, response, f_args)
+
+    def open_orders(self):
+        """
+        Get open orders.
+
+        :return: Open orders
+        :rtype: dict
+        """
+
+        f_name = cf().f_code.co_name
+        f_args = self.__get_func_args(locals())
+
+        url = '/v1/odr/orders/?state=active,initial'
+
+        response = self._request(
+            f_name,
+            'GET',
+            url,
+            auth=True,
+        )
+
+        return self._process_response(f_name, response, f_args)
